@@ -1,5 +1,5 @@
 """
-pnumpy: Distributed array
+pnumpy: Parallel numpy array
 """
 __all__ = ["pnDistArray", "pnGhostedDistArray", "pnMultiArrayIter", "pnCubeDecomp"]
 from pnDistArray import DistArray, daZeros, daOnes, daArray
